;
; =======================================================
;
;   9S12XDem.asm	9S12XDT512 Demo Program
;
;   Version:		1.0   03/01/2005
;   Author:		      Spencer Ruggles
;   Compiler:		WinIDE HCS12
;
;   Platform:		DEMO9S12XDT512, AXM-350
;   Purpose:		Flash LEDs and output text on COM
; =======================================================
;
$HCS12

#include (12XEqu.asm)		; register equates file
 

;========== Local Equates ===============================

REGBS:	equ $0			; reg base starts at 0
RAM:	equ $2000		; start of RAM
STACK:	equ $4000		; SP, top of RAM + 1
FLASH:	equ $C000		; Flash base

LED1:	equ $E0			; LED1 on
LED2:	equ $D0			; LED2 on
LED3:	equ $B0			; LED3 on
LED4:	equ $70			; LED4 on

PTBDIR:	equ $F0			; PTB[7:4] out,PTB[3:0] in
PTBPUL:	equ $02			; PTB pull enable
PTPPUL:	equ $03			; PTP pull enable [1:0]
PTPPOL:	equ $00			; PTP polarity fall edge

EOT:	equ $04			; end of text
;CHAR:	equ $2800		; location of text
RDRF:	equ $20			; Rx Data Reg Full
TDRE:	equ $80			; TX Data Reg Empty
TC:	equ $40			; Tx Complete Flag

; ========== PROGRAM ====================================
PSTART:
        org FLASH		; load program at FLASH base

SETUP:
	lds #STACK		; init SP
	sei			; interrutps off
        movb #$40,COPCTL	; COP off
	movb #PTBDIR,DDRB	; PTB[7:4] out, PTB[3:0] in 

; Setup communication ports.
; Initialize SCI0 for 9600 baud
; Using a 4 MHz clock, the Baud rate register value is
; calculated as follows:
;	BR = MCLK / (16 * Baud_Rate)
;	MCLK = crystal / 2
;	BR = 2,000,000 / (16 * 9600)
;	BR = 13 => 0D hex
; $0D = 9600 baud


ONSCI:
	clr SCI0BDH		; clear high baud com 1
	movb #$0D,SCI0BDL	; store low baud rate com 1

	clr SCI0CR1
	movb #$0c,SCI0CR2	; enable tx & rx, no ints on com1

PROG:

	movb #$10,PORTB		; LED1 on
	jsr DELAY		; wait
 	movb #$30,PORTB		; LED1,2 on
	jsr DELAY		; wait
	movb #$70,PORTB		; LED1,2,3 on
	jsr DELAY		; wait
	movb #$F0,PORTB	        ; LED1,2,3,4
	jsr DELAY		; wait

	movb #$E0,PORTB		; LED1 on
	jsr DELAY		; wait
 	movb #$C0,PORTB		; LED1,2 on
	jsr DELAY		; wait
	movb #$80,PORTB		; LED1,2,3 on
	jsr DELAY		; wait
	movb #$00,PORTB	        ; LED1,2,3,4
	jsr DELAY		; wait

SCI:				
	ldx #CHAR		; get output char
TEXT:
	ldaa 0,X		; move char to A
	cmpa #EOT		; last char?
	beq NEXT		; quit if last char
	jsr OUTCHAR0		; send data
	inx			; get next char
	bra TEXT		; loop until done
NEXT:
	jsr OUTCRLF0		; send CR/LF

EXIT:
	bra PROG		; loop forever	



; ========== SUB-ROUTINES ===============================

DELAY:

	psha			; store A
	pshx			; store X

	ldaa #$02		; outer loop count
DLYO:	ldx #$FFFF		; inner loop count
DLYI:	dex			; X = X-1
	bne DLYI		; inner delay loop
	deca
	bne DLYO		; outer delay loop

	pulx			; restore X
	pula			; restore A

	rts			; return

#include (SCIOut.asm)		; SCI output routines


; ========== OUTPUT STRING ===============================

	org FLASH+$400
CHAR:
	FCB 'Freescale DEMO9S12XDT512, AXM-0350'
	FCB EOT


; ========== RESET VECTOR ================================

	ORG $FFFE
	DW SETUP		; reset vector

;END:

